@@ -1,18 +1,17 @@
+""" rowantree.contracts namespace """
+
 from .dto.action.action import Action
 from .dto.action.action_queue import ActionQueue
-from .dto.merchant.merchant import Merchant
 from .dto.user.active import UserActive
 from .dto.user.event import UserEvent
 from .dto.user.feature import UserFeature
-from .dto.user.features import UserFeatures
 from .dto.user.income import UserIncome
-from .dto.user.incomes import UserIncomes
-from .dto.user.merchants import UserMerchants
 from .dto.user.notification import UserNotification
-from .dto.user.notifications import UserNotifications
 from .dto.user.population import UserPopulation
 from .dto.user.state import UserState
 from .dto.user.store import UserStore
-from .dto.user.stores import UserStores
 from .dto.user.user import User
 from .dto.world.status import WorldStatus
+from .feature_type import FeatureType
+from .store_type import StoreType
+from .user_event_other_type import UserEventOtherType
